@@ -1,4 +1,5 @@
 #!/usr/bin/env python2.5
+# coding= utf-8
 # 
 # Copyright (c) 2009 Daniel Would
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -82,11 +83,11 @@ class Witter():
         self.program = hildon.Program()
         self.program.__init__()
 
-        self.osso_c = osso.Context("witter","0.1.1", False) 
+        self.osso_c = osso.Context("witter","0.2.0", False) 
         # set name of application: this shows in titlebar
         gtk.set_application_name("Witter")
-        self.twitterUrlRoot = "http://twitter.com/"
-        self.twitterSearchUrlRoot = "http://search.twitter.com/"
+        self.twitterUrlRoot = "https://twitter.com/"
+        self.twitterSearchUrlRoot = "https://search.twitter.com/"
         self.twitterName = "Witter"
         self.identicaUrlRoot = "http://identi.ca/api/"
         self.identicaSearchUrlRoot = "http://identi.ca/api/"
@@ -95,12 +96,13 @@ class Witter():
         self.searchServiceUrlRoot = self.twitterSearchUrlRoot
         self.serviceName = self.twitterName
 	 #used to store the id of message if we're going to do a reply_to
-        self.reply_to=None
-        self.reply_to_name=None
-	self.retweetname=None
-	self.retweetid=None
+        self.reply_to=""
+        self.reply_to_name=""
+	self.retweetname=""
+	self.retweetid=""
+	self.retweettext=""
         #Set the Glade file
-       # self.gladefile = "/usr/share/witter/witter.glade"  
+        #self.gladefile = "/usr/share/witter/witter.glade"  
         #self.wTree = gtk.glade.XML(self.gladefile) 
         self.builder = gtk.Builder()
         self.builder.add_from_file("/usr/share/witter/witter.ui") 
@@ -199,15 +201,15 @@ class Witter():
         
         #self.urlmenu = gtk.Menu()
         # define a liststore we use this to store our tweets and some associated data
-        # the fields are : Name,nameColour,Tweet+Timestamp,TweetColour,id, type
-        self.liststore = gtk.ListStore(str, str, str, str, str, str)
+        # the fields are : Name,nameColour,Tweet,TweetColour,id, type, timestamp, replyTo
+        self.liststore = gtk.ListStore(str, str, str, str, str, str,str,str)
         #then we want the same again to store dm's, mentions & pubilc timeline separately
-        self.dmliststore = gtk.ListStore(str, str, str, str, str, str)
-        self.mentionliststore = gtk.ListStore(str, str, str, str, str, str)
-        self.publicliststore= gtk.ListStore(str, str, str, str, str, str)
-        self.trendliststore= gtk.ListStore(str, str, str, str)
-        self.friendsliststore = gtk.ListStore(str,str,str,str,str,str)
-        self.searchliststore = gtk.ListStore(str,str,str,str,str,str)
+        self.dmliststore = gtk.ListStore(str, str, str, str, str, str,str,str)
+        self.mentionliststore = gtk.ListStore(str, str, str, str, str, str,str,str)
+        self.publicliststore= gtk.ListStore(str, str, str, str, str, str,str,str)
+        self.trendliststore= gtk.ListStore(str, str, str, str,str,str,str,str)
+        self.friendsliststore = gtk.ListStore(str,str,str,str,str,str,str,str)
+        self.searchliststore = gtk.ListStore(str,str,str,str,str,str,str,str)
         #we want auto-complete of @references 
         #self.tweetText = self.wTree.get_widget("TweetText")
         self.tweetText = self.builder.get_object("TweetText")
@@ -227,9 +229,10 @@ class Witter():
         # create the TreeViewColumn to display the data, I decided on two colums
         # one for name and the other for the tweet
         #self.tvcname = gtk.TreeViewColumn('Name')
-        #cell = witter.witter_cell_renderer.witterCellRender()
-	cell = gtk.CellRendererText()
+        cell = witter.witter_cell_renderer.witterCellRender()
+	#cell = gtk.CellRendererText()
         cell.set_property('background',"#6495ED")
+	cell.set_property('font_size',18)
 	
 	self.tvctweet = gtk.TreeViewColumn('Pango Markup', cell, markup=2)
 
@@ -252,12 +255,14 @@ class Witter():
         # next we add a mapping to the tweet column, again the third field
         # in our list store is the tweet text
         self.tvctweet.add_attribute(cell, 'text',2)
+	self.tvctweet.add_attribute(cell, 'timestamp',6)
+	self.tvctweet.add_attribute(cell, 'replyto',7)
         # and the fourth is the colour of the tweet text 
         #self.tvctweet.add_attribute(cell, 'foreground', 3)
         # we start up non-fullscreen, and we want the tweets to appear without
         # scrolling left-right (well I wanted that) so I set a wrap width for
         # the text being rendered
-        cell.set_property('wrap-width', self.defaultwidth)
+        #cell.set_property('wrap-width', self.defaultwidth)
         # make it searchable (I found this in an example and thought I might use it
         # but currently I make no use of this setting
         self.treeview.set_search_column(2)
@@ -279,10 +284,12 @@ class Witter():
         self.treeview.set_reorderable(False)
         #with all that done I add the treeview to the scrolled window
         pannedWindow.add_with_viewport(self.treeview)
+	pannedWindow.connect('horizontal-movement', self.gesture)
+	pannedWindow.connect('vertical-movement', self.scrolling)
         #self.treeview.connect("button-press-event", self.build_menu, None);
         selection = self.treeview.get_selection()
         selection.connect('changed', self.build_menu)
-
+	
         # self.treeview.connect("changed", self.build_menu, None);
         self.treeview.tap_and_hold_setup(self.urlmenu, callback=gtk.tap_and_hold_menu_position_top)
 	#init the configDialog
@@ -383,7 +390,7 @@ class Witter():
         menu.append(Public)
         
         Creds = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
-        Creds.set_label("Set UID/PWD")
+        Creds.set_label("Authentication setup")
         # Attach callback to clicked signal
         Creds.connect("clicked", self.promptForCredentials)
         Creds.show()
@@ -397,7 +404,7 @@ class Witter():
         menu.append(Service)
 	
 	Properties= hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
-        Properties.set_label("Properties")
+        Properties.set_label("Preferences")
         # Attach callback to clicked signal
         Properties.connect("clicked", self.configProperties)
         Properties.show()
@@ -457,8 +464,15 @@ class Witter():
             self.getFriends()
         elif (self.treeview.get_model() == self.searchliststore):
             self.getSearch()
+	
+	self.builder.get_object("hbox1").hide_all()
+	self.builder.get_object("hbox2").hide_all()
+	
             
     def getTweets(self, auto=0, *args):
+	if (self.gettingTweets == True):
+		#already in this method in a refresh
+		return
 	self.gettingTweets = True
         print "getting tweets"
         #Now for the main logic...fetching tweets
@@ -490,11 +504,14 @@ class Witter():
             #then this line does all the hard work. Basicaly for evey top level object in the JSON
             #structure we call out getStatus method with the contents of the USER structure
             #and the values of top level values text/id/created_at
-	    [self.getStatus(x['user'],x['text'], x['id'], x['created_at'],x['in_reply_to_screen_name'], x['in_reply_to_status_id'], "tweet") for x in data]
-	    #hildon.hildon_banner_show_information(self.window,"","Tweets Received")
-	    note = osso.SystemNote(self.osso_c)
-
-	    result = note.system_note_infoprint("Tweets Received")
+	    receive_count = 0
+	    for x in data:
+		    self.getStatus(x['user'],x['text'], x['id'], x['created_at'],x['in_reply_to_screen_name'], x['in_reply_to_status_id'], "tweet")
+		    receive_count=receive_count +1
+		    
+	    if (receive_count > 0):
+		    note = osso.SystemNote(self.osso_c)
+		    result = note.system_note_infoprint(str(receive_count) + " Tweets Received")
 	    self.gettingTweets = False
         except IOError, e:
 	    print "error"
@@ -512,10 +529,10 @@ class Witter():
                 msg = msg +'Server returned ' + str(e.code) + " : " + reason
 	    if (auto==0):
 		    note = osso.SystemNote(self.osso_c)
-		    note.system_note_dialog(msg, type='notice')
+		    note.system_note_dialog(msg)
 
 	    self.gettingTweets = False
-
+	
           
         
     def getDMs(self, auto=0, *args):
@@ -547,10 +564,14 @@ class Witter():
             #then this line does all the hard work. Basicaly for evey top level object in the JSON
             #structure we call out getStatus method with the contents of the USER structure
             #and the values of top level values text/id/created_at
-            [self.getStatus(x['sender'],x['text'], x['id'], x['created_at'],None, None, "dm") for x in data]
-	    note = osso.SystemNote(self.osso_c)
-
-	    result = note.system_note_infoprint("DMs Received")
+            receive_count = 0
+	    for x in data:
+		    self.getStatus(x['sender'],x['text'], x['id'], x['created_at'],"", "", "dm")
+		    receive_count=receive_count +1
+		    
+	    if (receive_count > 0):
+		    note = osso.SystemNote(self.osso_c)
+		    result = note.system_note_infoprint(str(receive_count) + " DMs Received")
 	    self.gettingTweets = False
         except IOError, e:
             msg = 'Error retrieving DMs '
@@ -567,7 +588,7 @@ class Witter():
                 msg = msg +'Server returned ' + str(e.code) + " : " + reason
 	    if (auto==0):
 		    note = osso.SystemNote(self.osso_c)
-		    note.system_note_dialog(msg, type='notice')
+		    note.system_note_dialog(msg)
 	    self.gettingTweets = False
 
 
@@ -603,10 +624,16 @@ class Witter():
             #then this line does all the hard work. Basicaly for evey top level object in the JSON
             #structure we call out getStatus method with the contents of the USER structure
             #and the values of top level values text/id/created_at
-            [self.getStatus(x['user'],x['text'], x['id'], x['created_at'],x['in_reply_to_screen_name'], x['in_reply_to_status_id'], "mention") for x in data]
-	    note = osso.SystemNote(self.osso_c)
-
-	    result = note.system_note_infoprint("Mentions Received")
+            
+	    receive_count = 0
+	    for x in data:
+		    self.getStatus(x['user'],x['text'], x['id'], x['created_at'],x['in_reply_to_screen_name'], x['in_reply_to_status_id'], "mention")
+		    receive_count=receive_count +1
+		    
+	    if (receive_count > 0):
+		    note = osso.SystemNote(self.osso_c)
+		    result = note.system_note_infoprint(str(receive_count) + " Mentions Received")
+		    
 	    self.gettingTweets = False
         except IOError, e:
             msg = 'Error retrieving Mentions '
@@ -623,7 +650,7 @@ class Witter():
                 msg = msg +'Server returned ' + str(e.code) + " : " + reason
 	    if (auto==0):
 		    note = osso.SystemNote(self.osso_c)
-		    note.system_note_dialog(msg, type='notice')
+		    note.system_note_dialog(msg)
 	    self.gettingTweets = False
 
         
@@ -656,10 +683,14 @@ class Witter():
             #then this line does all the hard work. Basicaly for evey top level object in the JSON
             #structure we call out getStatus method with the contents of the USER structure
             #and the values of top level values text/id/created_at
-            [self.getStatus(x['user'],x['text'], x['id'], x['created_at'],x['in_reply_to_screen_name'], x['in_reply_to_status_id'], "public") for x in data]
-	    note = osso.SystemNote(self.osso_c)
-
-	    result = note.system_note_infoprint("Public timeline Received")
+            receive_count = 0
+	    for x in data:
+		    self.getStatus(x['user'],x['text'], x['id'], x['created_at'],x['in_reply_to_screen_name'], x['in_reply_to_status_id'], "public")
+		    receive_count=receive_count +1
+		    
+	    if (receive_count > 0):
+		    note = osso.SystemNote(self.osso_c)
+		    result = note.system_note_infoprint(str(receive_count) + " Public timeline tweets Received")
 	    self.gettingTweets = False
         except IOError, e:
             msg = 'Error retrieving Public timeline '
@@ -676,7 +707,7 @@ class Witter():
                 msg = msg +'Server returned ' + str(e.code) + " : " + reason
 	    if(auto==0):	
 		    note = osso.SystemNote(self.osso_c)
-		    note.system_note_dialog(msg, type='notice')
+		    note.system_note_dialog(msg)
 	    self.gettingTweets = False
 
             
@@ -749,9 +780,9 @@ class Witter():
 			else:
 			    reason = ""
 			msg = msg +'Server returned ' + str(e.code) + " : " + reason
-			
-		    note = osso.SystemNote(self.osso_c)
-		    note.system_note_dialog(msg, type='notice')
+		    if (auto ==0):
+			    note = osso.SystemNote(self.osso_c)
+			    note.system_note_dialog(msg)
 
 
             
@@ -802,12 +833,12 @@ class Witter():
                 msg = msg +'Server returned ' + str(e.code) + " : " + reason
 		
 	    note = osso.SystemNote(self.osso_c)
-	    note.system_note_dialog(msg, type='notice')
+	    note.system_note_dialog(msg)
 
             
     def getTrend(self, name, url):
         
-        self.trendliststore.append([name, self.namecolour,"<span foreground=\"blue\">"+name+"</span> :"+url,self.tweetcolour])
+        self.trendliststore.append([name, self.namecolour,name+" :"+url,self.tweetcolour,"","dm","",""])
         
         
     def getFriends(self, *args):
@@ -842,7 +873,7 @@ class Witter():
             for x in data:
                 #if we follow someone with no status then you get a key error on status
                 try:
-                    self.getStatus(x['screen_name'],x['status'], x['id'], x['created_at'],None,None, "friend") 
+                    self.getStatus(x['screen_name'],x['status'], x['id'], x['created_at'],"","", "friend") 
                 except KeyError:
                     print  x
 	    note = osso.SystemNote(self.osso_c)
@@ -879,12 +910,12 @@ class Witter():
             if (None != in_reply_to_id):
                 print "reply to "+in_reply_to_screen_name
                 #we don't want anything showing up if there is no reply_to, so all teh formatting is held here including the newline
-                reply_to = "\n<span size=\"xx-small\">In reply to: "+in_reply_to_screen_name+" - " + self.get_specific_tweet(in_reply_to_screen_name, in_reply_to_id)+"</span>"
+                reply_to = "In reply to: "+in_reply_to_screen_name+" - " + self.get_specific_tweet(in_reply_to_screen_name, in_reply_to_id)
             else:
                 reply_to=""
             data = data.replace("&","&amp;")
             reply_to = reply_to.replace("&","&amp;")
-            self.liststore.append([ "@"+user['screen_name'],self.namecolour,"<span foreground=\"#0000FF\"><b>@"+user['screen_name']+"</b></span> : "+data+"\n<span size=\"xx-small\">posted on: "+created_at+"</span>"+reply_to,self.tweetcolour, id, type])
+            self.liststore.append([ "@"+user['screen_name'],self.namecolour,"@"+user['screen_name']+" : "+data,self.tweetcolour, id, type, created_at,reply_to])
             #now we process the id, this is so we can do a refresh with just the posts since the latest one we have
             #if we haven't stored the most recent id then store this one
             if self.last_id == None:
@@ -894,8 +925,9 @@ class Witter():
                 if long(self.last_id) < long(id):
                     self.last_id=id
         elif (re.search("dm", type)):
+	    reply_to=""
             data = data.replace("&","&amp;")
-            self.dmliststore.append([ "@"+user['screen_name'],self.namecolour,"<span foreground=\"#0000FF\"><b>@"+user['screen_name']+"</b></span> : "+data+"\n<span size=\"xx-small\">posted on: "+created_at+"</span>",self.tweetcolour, id, type])
+            self.dmliststore.append([ "@"+user['screen_name'],self.namecolour,"@"+user['screen_name']+" : "+data,self.tweetcolour, id, type, created_at,reply_to])
             if self.last_dm_id == None:
                 self.last_dm_id=id
             else:
@@ -906,12 +938,12 @@ class Witter():
             if (None != in_reply_to_id):
                 print "reply to "+in_reply_to_screen_name
                 #we don't want anything showing up if there is no reply_to, so all teh formatting is held here including the newline
-                reply_to = "\n<span size=\"xx-small\">In reply to: "+in_reply_to_screen_name+" - " + self.get_specific_tweet(in_reply_to_screen_name, in_reply_to_id)+"</span>"
+                reply_to = "In reply to: "+in_reply_to_screen_name+" - " + self.get_specific_tweet(in_reply_to_screen_name, in_reply_to_id)
             else:
                 reply_to=""
             data = data.replace("&","&amp;")
             reply_to = reply_to.replace("&","&amp;")
-            self.mentionliststore.append([ "@"+user['screen_name'],self.namecolour,"<span foreground=\"#0000FF\"><b>@"+user['screen_name']+"</b></span> : "+data+"\n<span size=\"xx-small\">posted on: "+created_at+"</span>"+reply_to,self.tweetcolour, id, type])
+            self.mentionliststore.append([ "@"+user['screen_name'],self.namecolour,"@"+user['screen_name']+" : "+data,self.tweetcolour, id, type, created_at,reply_to])
             if self.last_mention_id == None:
                 self.last_mention_id=id
             else:
@@ -922,12 +954,12 @@ class Witter():
             if (None != in_reply_to_id):
                 print "reply to "+in_reply_to_screen_name
                 #we don't want anything showing up if there is no reply_to, so all teh formatting is held here including the newline
-                reply_to = "\n<span size=\"xx-small\">In reply to: "+in_reply_to_screen_name+" - " + self.get_specific_tweet(in_reply_to_screen_name, in_reply_to_id)+"</span>"
+                reply_to = "In reply to: "+in_reply_to_screen_name+" - " + self.get_specific_tweet(in_reply_to_screen_name, in_reply_to_id)
             else:
                 reply_to=""
             data = data.replace("&","&amp;")
             reply_to = reply_to.replace("&","&amp;")
-            self.publicliststore.append([ "@"+user['screen_name'],self.namecolour,"<span foreground=\"#0000FF\"><b>@"+user['screen_name']+"</b></span> : "+data+"\n<span size=\"xx-small\">posted on: "+created_at+"</span>"+reply_to,self.tweetcolour, id, type])
+            self.publicliststore.append([ "@"+user['screen_name'],self.namecolour,"@"+user['screen_name']+" : "+data,self.tweetcolour, id, type, created_at,reply_to])
             if self.last_public_id == None:
                 self.last_public_id=id
             else:
@@ -935,21 +967,22 @@ class Witter():
                 if long(self.last_public_id) < long(id):
                     self.last_public_id=id
         elif (re.search("friend", type)):
+	    reply_to=""
             text_data = data['text'].replace("&","&amp;")
-            self.friendsliststore.append([ "@"+user,self.namecolour,"<span foreground=\"#0000FF\"><b>@"+user+"</b></span> : "+text_data+"\n<span size=\"xx-small\">posted on: "+data['created_at']+"</span>",self.tweetcolour, id, type])
+            self.friendsliststore.append([ "@"+user,self.namecolour,"@"+user+" : "+text_data,self.tweetcolour, id, type, created_at,reply_to])
         elif (re.search("search", type)):
-            
+            reply_to=""
             data = data.replace("&","&amp;")
             
-            self.searchliststore.append([ "@"+user,self.namecolour,"<span foreground=\"#0000FF\"><b>@"+user+"</b></span> : "+data+"\n<span size=\"xx-small\">posted on: "+created_at+"</span>",self.tweetcolour, id, type])
+            self.searchliststore.append([ "@"+user,self.namecolour,"@"+user+" : "+data,self.tweetcolour, id, type, created_at,reply_to])
             
                 
     def enterPressed(self,widget,*args):
-	    #in most views we want to call newTweet, but in search call the getSearch
+	    self.newTweet(self,widget,*args)
+	    #if we were in the search view, we want to restore the search terms after a tweet
 	    if (self.treeview.get_model() == self.searchliststore):
-		self.getSearch()
-	    else:
-		self.newTweet(self,widget,*args)
+		self.tweetText.set_text(self.search_terms)
+	    
 	    
     def newTweet(self, widget, *args):
         #The other main need of a twitter client
@@ -1069,7 +1102,9 @@ class Witter():
     def on_key_press(self, widget, event, *args): 
         #this picks up the press of the full screen key and toggles
         #from one mode to the other
-       if event.keyval == gtk.keysyms.F6: 
+	self.builder.get_object("hbox1").show_all()
+	self.builder.get_object("hbox2").show_all()
+        if event.keyval == gtk.keysyms.F6: 
              # The "Full screen" hardware key has been pressed 
              if self.window_in_fullscreen: 
                  self.window.unfullscreen () 
@@ -1155,6 +1190,7 @@ class Witter():
                 self.menuItemUserAction.set_submenu(menuUserAct)
 		self.reply_to = id
 		self.reply_to_name= name
+		self.retweettext = entry
                 self.retweetname = name
 		self.retweetid = id
 		
@@ -1222,53 +1258,61 @@ class Witter():
         print data
     
     def replyTo(self, widget, *args):
-        print "reply to : " + self.reply_to_name + " message_id " + self.reply_to
-        self.tweetText.set_text(self.reply_to_name)
+	if (self.treeview.get_model() == self.searchliststore):
+		#we want to store the search terms, replace them with tweet text
+		#so we can restore the search terms afterwards
+		self.search_terms = self.tweetText.get_text()
+        self.tweetText.set_text(self.reply_to_name + " ")
+	self.tweetText.grab_focus()
+	self.tweetText.set_position(len(self.reply_to_name)+1);
         
-    
-    def reTweet(self, widget,  *args):
-        print "reTweet : " + self.retweetname + " message_id " +self.retweetid
-        
-	post = urllib.urlencode({ })
-        #build the request with the url and our post data
-        req = urllib2.Request('http://api.twitter.com/1/statuses/retweet/'+str(self.retweetid)+'L.json', post)
+    def reTweet(self,widget,*args):
+	    self.tweetText.set_text("RT:" + self.retweettext)
+	    self.tweetText.grab_focus()
+  
+  #      print "reTweet : " + self.retweetname + " message_id " +self.retweetid
+    #    #
+#	post = urllib.urlencode({ })
+   #     #build the request with the url and our post data
+   #     req = urllib2.Request('http://api.twitter.com/1/statuses/retweet/'+str(self.retweetid)+'L.json', post)
         #setup the auth stuff
-        auth_handler = urllib2.HTTPBasicAuthHandler()
-        auth_handler.add_password(realm='Twitter API',
-                              uri='http://api.twitter.com/1/statuses/retweet/'+str(self.retweetid)+'L.json',
-                              user=self.username,
-                              passwd=self.password)
-        opener = urllib2.build_opener(auth_handler)
+ #       auth_handler = urllib2.HTTPBasicAuthHandler()
+  #      auth_handler.add_password(realm='Twitter API',
+   #                           uri='http://api.twitter.com/1/statuses/retweet/'+str(self.retweetid)+'L.json',
+     #                         user=self.username,
+       #                       passwd=self.password)
+    #    opener = urllib2.build_opener(auth_handler)
         # ...and install it globally so it can be used with urlopen.
-	try:
-		urllib2.install_opener(opener)
-		json = urllib2.urlopen(req)
-		hildon.hildon_banner_show_information(self.window,"","ReTweet Successful")
-	except IOError, e:
-	    msg = 'Error posting tweet '
-	    if hasattr(e, 'reason'):
-		    msg = msg + str(e.reason)
-		    
-            if hasattr(e, 'code'):
-                if (e.code == 401):
-                    reason = "Not authorised: check uid/pwd"
-		elif(e.code == 503):
-		    reason = "Service unavailable"
-                else:
-                    reason = ""
-                msg = msg +'Server returned ' + str(e.code) + " : " + reason
+#	try:
+#		urllib2.install_opener(opener)
+#		json = urllib2.urlopen(req)
+#		hildon.hildon_banner_show_information(self.window,"","ReTweet Successful")
+#	except IOError, e:
+#	    msg = 'Error posting tweet '
+#	    if hasattr(e, 'reason'):
+#		    msg = msg + str(e.reason)
+#		    
+   #         if hasattr(e, 'code'):
+      #          if (e.code == 401):
+         #           reason = "Not authorised: check uid/pwd"
+	#	elif(e.code == 503):
+	#	    reason = "Service unavailable"
+           #     else:
+              #      reason = ""
+                #msg = msg +'Server returned ' + str(e.code) + " : " + reason
 		
-	    note = hildon.hildon_note_new_information(self.window, msg)
-            note.run()
-	    note.destroy()
+#	    note = hildon.hildon_note_new_information(self.window, msg)
+   #         note.run()
+	#    note.destroy()
 	
     def openBrowser(self, widget, url, *args):      
         #open a url in a browser
-        context = osso.Context("Witter", "1.0",False)
         if (self.maemo_ver==5):
+	    print "opening browser - maemo5 style"
             webbrowser.open_new(url)
         else:
-            webbrowser.open(url, context=context)
+	    print "opening browser - maemo4 style"
+            webbrowser.open(url, context=self.osso_c)
         print "We tried to open a browser"
         
     def checkVersion(self):
@@ -1422,6 +1466,9 @@ class Witter():
 	    self.tweetText.set_text(self.search_terms)
             self.treeview.set_model(self.searchliststore)  
             self.window.set_title(self.serviceName +" - search")  
+	    
+	self.builder.get_object("hbox1").show_all()
+	self.builder.get_object("hbox2").show_all()
             
     def switchView(self, widget):
         #switches the active liststore to display what the user wants
@@ -1462,62 +1509,7 @@ class Witter():
 
 
         
-    def flipTextColour(self, *args):
-        #until I figure out how to obey theme colours, let the user
-        #flip the colours in use.
-        if (re.search("#000000", self.textcolour)):
-            self.textcolour = "#FFFFFF"
-            
-        else:
-            self.textcolour = "#000000"
-        #reset all the values in the current list stores
-        item = self.liststore.get_iter_first ()
-
-        while ( item != None ):
-            self.liststore.set_value(item,1,self.textcolour)
-            self.liststore.set_value(item,3,self.textcolour)
-            item = self.liststore.iter_next(item)
-        
-        item = self.dmliststore.get_iter_first ()
-
-        while ( item != None ):
-            self.dmliststore.set_value(item,1,self.textcolour)
-            self.dmliststore.set_value(item,3,self.textcolour)
-            item = self.dmliststore.iter_next(item)
-        item = self.friendsliststore.get_iter_first ()
-
-        while ( item != None ):
-            self.friendsliststore.set_value(item,1,self.textcolour)
-            self.friendsliststore.set_value(item,3,self.textcolour)
-            item = self.friendsliststore.iter_next(item)
-        
-        item = self.mentionliststore.get_iter_first ()
-
-        while ( item != None ):
-            self.mentionliststore.set_value(item,1,self.textcolour)
-            self.mentionliststore.set_value(item,3,self.textcolour)
-            item = self.mentionliststore.iter_next(item)
-        item = self.publicliststore.get_iter_first ()
-
-        while ( item != None ):
-            self.publicliststore.set_value(item,1,self.textcolour)
-            self.publicliststore.set_value(item,3,self.textcolour)
-            item = self.publicliststore.iter_next(item)
-        
-        item = self.searchliststore.get_iter_first ()
-
-        while ( item != None ):
-            self.searchliststore.set_value(item,1,self.textcolour)
-            self.searchliststore.set_value(item,3,self.textcolour)
-            item = self.searchliststore.iter_next(item)
-            
-        item = self.trendliststore.get_iter_first ()
-
-        while ( item != None ):
-            self.trendliststore.set_value(item,1,self.textcolour)
-            self.trendliststore.set_value(item,3,self.textcolour)
-            item = self.trendliststore.iter_next(item)
-      
+       
     def twitPic(self, widget, *args):
         print "twitPic"
         #dialog = self.wTree.get_widget("filechooserdialog1")
@@ -1560,6 +1552,7 @@ class Witter():
         print file
     
     def CharsRemaining(self, widget):
+	     self.builder.get_object("hbox1").show_all()
 	     tweet = self.builder.get_object("TweetText").get_text()
 	     counter = self.builder.get_object("Counter")
 	     counter.set_text((str(140-len(tweet))))
@@ -1569,7 +1562,8 @@ class Witter():
 		dlg = gtk.AboutDialog()
 		dlg.set_version("0.1.1")
 		dlg.set_name("Witter")
-		dlg.set_authors(["Daniel Would (programmer)", "@mece66 (logo)"])
+		#"Marcus Wikstrm (logo)"
+		dlg.set_authors(["Daniel Would (programmer)", u"Marcus Wikström (logo)"])
 		dlg.set_website("Homepage : http://danielwould.wordpress.com/witter/\nBugtracker : http://garage.maemo.org/projects/witter")
 		def close(w, res):
 			if res == gtk.RESPONSE_CANCEL:
@@ -1686,7 +1680,47 @@ class Witter():
 	    print "running"
 	    return "still running"
 	    
+	
+    def gesture(self, widget, direction, startx, starty):
+	     
+	     widget.scroll_to(0,0)
+	     if (direction == 3):
+		if (self.treeview.get_model() == self.liststore):
+		    self.switchViewTo(self.treeview, "public")
+		elif (self.treeview.get_model() == self.dmliststore):
+		    self.switchViewTo(self.treeview, "mentions")
+		elif (self.treeview.get_model() == self.mentionliststore):
+		    self.switchViewTo(self.treeview, "timeline")
+		elif (self.treeview.get_model() == self.publicliststore):
+		    self.switchViewTo(self.treeview, "trends")
+		elif (self.treeview.get_model() == self.trendliststore):
+		    self.switchViewTo(self.treeview, "friends")
+		elif (self.treeview.get_model() == self.friendsliststore):
+		    self.switchViewTo(self.treeview, "search")
+		elif (self.treeview.get_model() == self.searchliststore):
+		    self.switchViewTo(self.treeview, "direct")
+		
+		    
+	     if (direction == 2):
+		if (self.treeview.get_model() == self.liststore):
+		    self.switchViewTo(self.treeview, "mentions")
+		elif (self.treeview.get_model() == self.dmliststore):
+		    self.switchViewTo(self.treeview, "search")
+		elif (self.treeview.get_model() == self.mentionliststore):
+		    self.switchViewTo(self.treeview, "direct")
+		elif (self.treeview.get_model() == self.publicliststore):
+		    self.switchViewTo(self.treeview, "timeline")
+		elif (self.treeview.get_model() == self.trendliststore):
+		    self.switchViewTo(self.treeview, "public")
+		elif (self.treeview.get_model() == self.friendsliststore):
+		    self.switchViewTo(self.treeview, "trends")
+		elif (self.treeview.get_model() == self.searchliststore):
+		    self.switchViewTo(self.treeview, "friends")    
 	    
+    def scrolling (self, widget, direction, startx, starty):
+	     self.builder.get_object("hbox1").hide_all()
+	     self.builder.get_object("hbox2").hide_all()
+	
 if __name__ == "__main__":  
     #this is just what initialises the app and calls run
     app = Witter() 
